@@ -55,6 +55,9 @@ class CLI(cl1.CLI):
 			options={
 				"-j / --json":"Print the response in json format.",
 			},
+			notes={
+				"SSHT00LS_CONFIG":"Specify the $SSHT00LS_CONFIG environment variable to use a different ssht00ls config file.",
+			},
 			alias=ALIAS,
 			executable=__file__,
 		)
@@ -142,7 +145,7 @@ class CLI(cl1.CLI):
 			path = self.get_argument("--pull", index=1)
 			remote = self.get_argument("--pull", index=2)
 			if ":" not in remote:
-				r3sponse.log(error=f"Invalid <alias>:<remote> format: {remote}.", json=json)
+				r3sponse.log(error=f"Invalid <path> <alias>:<remote> format.", json=json)
 				self.stop()
 			alias,remote = remote.split(":")
 			exclude = None
@@ -164,7 +167,7 @@ class CLI(cl1.CLI):
 			remote = self.get_argument("--push", index=1)
 			path = self.get_argument("--push", index=2)
 			if ":" not in remote:
-				r3sponse.log(error=f"Invalid <alias>:<remote> format: {remote}.", json=json)
+				r3sponse.log(error=f"Invalid <alias>:<remote> <path>.", json=json)
 				self.stop()
 			alias,remote = remote.split(":")
 			exclude = None
@@ -186,7 +189,7 @@ class CLI(cl1.CLI):
 			remote = self.get_argument("--mount", index=1)
 			path = self.get_argument("--mount", index=2)
 			if ":" not in remote:
-				r3sponse.log(error=f"Invalid <alias>:<remote> format: {remote}.", json=json)
+				r3sponse.log(error=f"Invalid <alias>:<remote> <path>.", json=json)
 				self.stop()
 			alias,remote = remote.split(":")
 			response = ssht00ls.ssync.mount(
@@ -221,7 +224,7 @@ class CLI(cl1.CLI):
 			remote = self.get_argument("--start-daemon", index=1)
 			path = self.get_argument("--start-daemon", index=2)
 			if ":" not in remote:
-				r3sponse.log(error=f"Invalid <alias>:<remote> format: {remote}.", json=json)
+				r3sponse.log(error=f"Invalid <alias>:<remote> <path>.", json=json)
 				self.stop()
 			alias,remote = remote.split(":")
 			response = ssht00ls.ssync.daemon(alias=alias, remote=remote, path=path)
@@ -245,12 +248,15 @@ class CLI(cl1.CLI):
 
 		#
 	def invalid(self):
-		print(self.documentation)
 		if json:
 			r3sponse.log(error="Selected an invalid mode.", json=json)
 		else:
+			print(self.documentation)
 			print("Selected an invalid mode.")
 		#
+	def stop(self, success=False):
+		if success: sys.exit(1)
+		else:sys.exit(1)
 	def get_passphrase(self, required=True):
 		return self.get_argument("--passphrase", required=required).replace("\\", "").replace("\ ", "")
 # main.
