@@ -274,7 +274,7 @@ class Agent(object):
 		return response
 
 		#
-	def check(self, public_key=None):
+	def check(self, public_key=None, raw=False):
 		
 		# initialize.
 		response = utils.__default_response__()		
@@ -284,16 +284,17 @@ class Agent(object):
 		if not success: return response
 
 		# checks.
-		if not os.path.exists(public_key):
+		if not raw and not os.path.exists(public_key):
 			response["error"] = f"Public key path [{public_key}] does not exist."
 			return response
 
 		# load public key.
-		try:
-			public_key = utils.__load_file__(public_key)
-		except:
-			response["error"] = f"Failed to load public key path [{public_key}]."
-			return response
+		if not raw:
+			try:
+				public_key = utils.__load_file__(public_key)
+			except:
+				response["error"] = f"Failed to load public key path [{public_key}]."
+				return response
 
 		# retrieve id from public key.
 		"""
