@@ -4,6 +4,7 @@
 # imports.
 from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
+from ssht00ls.classes.agent import agent
 
 # the aliases object class.
 class Aliases(object):
@@ -31,10 +32,11 @@ class Aliases(object):
 		# the port of the server.
 		public_port=None,
 		private_port=None,
-		# the path to the private key.
-		key=None,
+		# the path to the private & public key.
+		private_key=None,
+		public_key=None,
 		# the keys passphrase.
-		passhrase=None,
+		passphrase=None,
 		# smart card.
 		smart_card=False,
 		# the smart cards pincode.
@@ -47,7 +49,7 @@ class Aliases(object):
 		
 		# serialized
 		if serialized != {}:
-			try:username = serialized["username"]
+			try:username = serialized["user"]
 			except KeyError: username = None
 			try:public_ip = serialized["public_ip"]
 			except KeyError: public_ip = None
@@ -57,8 +59,10 @@ class Aliases(object):
 			except KeyError: public_port = None
 			try:private_port = serialized["private_port"]
 			except KeyError: private_port = None
-			try:key = serialized["key"]
-			except KeyError: key = None
+			try:private_key = serialized["private_key"]
+			except KeyError: private_key = None
+			try:public_key = serialized["public_key"]
+			except KeyError: public_key = None
 			try:passphrase = serialized["passphrase"]
 			except KeyError: passphrase = None
 			try:smart_card = serialized["smart_card"]
@@ -76,7 +80,8 @@ class Aliases(object):
 			"private_ip":private_ip,
 			"public_port":public_port,
 			"private_port":private_port,
-			"key":key,
+			"private_key":private_key,
+			"public_key":public_key,
 		}, empty_value=None)
 		if not success: return response
 		if smart_card:
@@ -89,7 +94,8 @@ class Aliases(object):
 				"passphrase":passphrase,
 			}, empty_value=None)
 			if not success: return response
-		key = syst3m.env.fill(key)
+		private_key = syst3m.env.fill(private_key)
+		public_key = syst3m.env.fill(public_key)
 		json_config = {}
 		if NETWORK_INFO["public_ip"] == public_ip:
 			ip = private_ip
@@ -111,12 +117,13 @@ class Aliases(object):
 		config += "\n    ForwardAgent yes"
 		config += "\n    PubKeyAuthentication yes"
 		#config += "\n    IdentitiesOnly yes"
+		json_config["public_key"] = public_key
 		if not smart_card:
-			json_config["key"] = key
+			json_config["private_key"] = private_key
 			json_config["smart_card"] = False
-			config += "\n    IdentityFile {}".format(key)
+			config += "\n    IdentityFile {}".format(private_key)
 		else:
-			json_config["key"] = smart_cards.path
+			json_config["private_key"] = smart_cards.path
 			json_config["smart_card"] = True
 			config += "\n    PKCS11Provider {}".format(smart_cards.path)
 
@@ -128,9 +135,9 @@ class Aliases(object):
 				if not response["success"]: return response
 				CONFIG["aliases"][alias]["pin"] = response["encrypted"].decode()
 			else:
-				response = ENCRYPTION.encrypt(str(passhrase))
+				response = ENCRYPTION.encrypt(str(passphrase))
 				if not response["success"]: return response
-				CONFIG["aliases"][alias]["passhrase"] = response["encrypted"].decode()
+				CONFIG["aliases"][alias]["passphrase"] = response["encrypted"].decode()
 			CONFIG.save()
 
 		# response.
@@ -147,20 +154,52 @@ class Aliases(object):
 		if include not in Files.load(f"{HOME}/.ssh/config"):
 			Files.save(f"{HOME}/.ssh/config", Files.load(f"{HOME}/.ssh/config")+"\n"+include+"\n")
 		aliases, c = "", 0
-		for alias, info in CONFIG["aliases"].items():
+		for alias in list(CONFIG["aliases"].keys()):
+			info = CONFIG["aliases"][alias]
 			if "example.com " not in alias:
 				checked = Files.Dictionary(path=False, dictionary=info).check(default={
-					"alias":None,
-					"username":None,
+					"user":None,
 					"public_ip":None,
 					"private_ip":None,
 					"public_port":None,
 					"private_port":None,
-					"key":None,
-					"passhrase":None,
+					"private_key":None,
+					"public_key":None,
+					"passphrase":None,
 					"smart_card":None,
 					"pin":None,
 				})
+				if isinstance(checked["private_key"], str):
+					checked["private_key"] = syst3m.env.fill(checked["private_key"])
+				if isinstance(checked["public_key"], str):
+					checked["public_key"] = syst3m.env.fill(checked["public_key"])
+				if not cl1.argument_present("--non-interactive"):
+					passphrase = None
+					if checked["smart_card"] and checked["pin"] in [None, "", "none", "None"]:
+						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['key']}:")
+					elif checked["passphrase"] in [None, "", "none", "None"]:
+						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['key']}:")
+					if checked["smart_card"]:
+						response = agent.check(public_key=checked["public_key"], raw=True)
+					else:
+						response = agent.check(public_key=checked["public_key"], raw=False)
+					if not response["success"]:
+						if "is not added" not in response["error"]: return response
+						elif "is not added" in response["error"]:
+							if checked["smart_card"]:
+								response = agent.add(path=checked["private_key"], smart_card=True, pin=passphrase)
+								if not response["success"]: return response
+							else:
+								response = agent.add(path=checked["private_key"], passphrase=passphrase)
+								if not response["success"]: return response
+					if passphrase != None:
+						response = ENCRYPTION.encrypt(passphrase)
+						if not response.success: return response
+						if checked["smart_card"]:
+							CONFIG["aliases"][alias]["pin"] = response.encrypted.decode()
+						else:
+							CONFIG["aliases"][alias]["passphrase"] = response.encrypted.decode()
+						CONFIG.save()
 				response = self.create(save=False, serialized=checked)
 				if not response["success"]: return response
 				aliases += response["str"]
