@@ -177,7 +177,7 @@ class SSync(object):
 		if exclude == None: exclude = self.exclude
 		exclude_str = ""
 		for i in exclude: exclude_str += f"--exclude {i} "
-		delete_str = utils.convert_bool(delete, true="--delete", false="")
+		delete_str = Formats.Boolean(delete).convert(true="--delete", false="")
 		command = f"rsync -azP {alias}:{remote} {path} {exclude_str}{delete_str}"
 		output = syst3m.utils.__execute_script__(command)
 		cache.set(id=path, data="*mounted*", group="daemons")
@@ -224,7 +224,7 @@ class SSync(object):
 		if exclude == None: exclude = self.exclude
 		exclude_str = ""
 		for i in exclude: exclude_str += f"--exclude {i} "
-		delete_str = utils.convert_bool(delete, true="--delete", false="")
+		delete_str = Formats.Boolean(delete).convert(true="--delete", false="")
 		command = f"rsync -azP {path} {alias}:{remote} {exclude_str}{delete_str}"
 		output = syst3m.utils.__execute_script__(command)
 		# handler.
