@@ -5,6 +5,40 @@
 from ssht00ls.classes.config import * 
 import os, sys, requests, ast, json, pathlib, glob, string, getpass, django
 
+# test ssh functions.
+def test_ssh(alias=None, accept_new_host_keys=True,):
+	accept_new_host_keys = Formats.Boolean(accept_new_host_keys).convert(true="printf 'yes' | ", false="")
+	output = syst3m.utils.__execute_script__(f"""{accept_new_host_keys}ssh {alias} ' echo "Hello World" ' """)
+	if "Hello World" in output:
+		return r3sponse.success_response(f"Successfully connected with {alias}.")
+	else:
+		return r3sponse.error_response(f"Failed to connect with {alias}, error: {output}")
+def test_ssh_path(alias=None, path=None, accept_new_host_keys=True,):
+	response = test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
+	if not response.success: return response
+	output = syst3m.utils.__execute_script__(f"""ssh {alias} ' ls -ld {path} ' """)
+	if "No such file or directory" not in output:
+		return r3sponse.success_response(f"Path {alias}:{path} exists.")
+	else:
+		return r3sponse.error_response(f"Path {alias}:{path} does not exist.")
+def test_ssht00ls(alias=None, accept_new_host_keys=True, install=True):
+	path = f"/usr/local/lib/{ALIAS}"
+	response = test_ssh_path(alias=alias, accept_new_host_keys=accept_new_host_keys, path=path)
+	if not response.success:
+		if response.error == f"Path {alias}:{path} does not exist.":
+			if install:
+				loader = syst3m.console.Loader(f"Installing ssht00ls library on remote {alias}.")
+				output = syst3m.utils.__execute_script__(f"ssh {alias} ' curl https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote | bash ' ")
+				response = test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys, install=False)
+				loader.stop(success=response.success)
+				print(output)
+				return response
+			else:
+				return r3sponse.error_response(f"Remote {alias} does not have library ssht00ls installed.")
+		else:
+			return response
+	return r3sponse.success_response(f"Remote {alias} has library ssht00ls installed.")
+
 # check / start the ssh agent.
 def ssh_agent():
 	"""
@@ -58,7 +92,6 @@ def kill_ssh(identifier=None, sudo=False, dont_kill=["grep", "ssht00ls"]):
 					r3sponse.log(f"Failed to stop process {pid}, error: {output}")
 	return r3sponse.success_response(f"Successfully killed {killed} process(es) that included identifier [{identifier}].")
 
-
 # init a default response.
 def __default_response__():
 	return {
